/**
 * IMPORTANT: Changes in this file MUST be duplicated in edge-react-gui!
 */
import * as React from 'react';
import { FlatList, Keyboard } from 'react-native';
import { useFilter } from '../../hooks/useFilter';
import { SearchIconAnimated } from '../icons/ThemedIcons';
import { useTheme } from '../services/ThemeContext';
import { ModalFooter, ModalMessage, ModalTitle } from '../themed/ModalParts';
import { SimpleTextInput } from '../themed/SimpleTextInput';
import { ThemedModal } from '../themed/ThemedModal';
export function ListModal({ bridge, title, message, hideSearch = false, initialValue = '', rowsData = [], rowComponent, rowDataFilter, closeArrow = true, onSubmitEditing, onViewableItemsChanged, 
// SimpleTextInput props:
iconComponent = SearchIconAnimated, placeholder, autoCorrect = false, autoCapitalize = 'words', returnKeyType = 'search', keyboardType, blurOnSubmit, inputAccessoryViewID, maxLength, secureTextEntry, autoFocus, blurOnClear = false }) {
    const theme = useTheme();
    const [text, setText] = React.useState(initialValue);
    const [filteredRows, setFilteredRows] = useFilter(rowsData, rowDataFilter);
    const renderItem = ({ item }) => rowComponent ? rowComponent(item) : null;
    const handleCancel = () => bridge.resolve(undefined);
    const handleChangeText = (text) => {
        setText(text);
        setFilteredRows(text);
    };
    const handleSubmitEditing = () => onSubmitEditing != null ? onSubmitEditing(text) : bridge.resolve(text);
    const scrollPadding = React.useMemo(() => {
        return { paddingBottom: theme.rem(ModalFooter.bottomRem) };
    }, [theme]);
    return (React.createElement(ThemedModal, { bridge: bridge, closeButton: closeArrow, onCancel: handleCancel },
        title == null ? null : React.createElement(ModalTitle, null, title),
        message == null ? null : React.createElement(ModalMessage, null, message),
        hideSearch ? null : (React.createElement(SimpleTextInput, { vertical: 1, horizontal: 0.5, 
            // Our props:
            testID: title, onChangeText: handleChangeText, onSubmitEditing: handleSubmitEditing, value: text, 
            // Outlined Text input props:
            iconComponent: iconComponent, placeholder: placeholder, autoCorrect: autoCorrect, autoCapitalize: autoCapitalize, returnKeyType: returnKeyType, keyboardType: keyboardType, blurOnSubmit: blurOnSubmit, inputAccessoryViewID: inputAccessoryViewID, maxLength: maxLength, secureTextEntry: secureTextEntry, autoFocus: autoFocus, blurOnClear: blurOnClear })),
        React.createElement(FlatList, { contentContainerStyle: scrollPadding, data: filteredRows, keyboardShouldPersistTaps: "handled", keyExtractor: (_, i) => `${i}`, renderItem: renderItem, onScroll: () => Keyboard.dismiss(), onViewableItemsChanged: onViewableItemsChanged })));
}
